//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by FernFlower decompiler)
//

package kd.imc.rim.common.invoice.recognition.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import java.util.Map;
import java.util.concurrent.Callable;
import kd.bos.context.RequestContext;
import kd.bos.dataentity.utils.StringUtils;
import kd.bos.dlock.DLock;
import kd.bos.logging.Log;
import kd.bos.logging.LogFactory;
import kd.bos.orm.util.CollectionUtils;
import kd.imc.rim.common.constant.ResultContant;
import kd.imc.rim.common.invoice.fpzs.FpzsMainService;
import kd.imc.rim.common.invoice.recognition.listener.IRecognitionListener;
import kd.imc.rim.common.service.EInvoiceZipXmlDealService;
import kd.imc.rim.common.service.ElectAccVoucherService;
import kd.imc.rim.common.service.ExcelInvoiceUploadService;
import kd.imc.rim.common.service.RecognitionCheckServiceEx;
import kd.imc.rim.common.utils.CacheHelper;
import kd.imc.rim.common.utils.FileUtils;
import kd.imc.rim.common.utils.MD5;
import org.apache.commons.lang3.tuple.Pair;

public class RecognitionCheckTaskEx implements Callable<JSONObject> {
    private static Log logger = LogFactory.getLog(RecognitionCheckTaskEx.class);
    private static int cache_time_out = 1800;
    private JSONObject businessParam;
    private Map<String, Object> customParam;
    private String url;
    private String fileName;
    private String pageId;
    private String source;
    private RequestContext ctx;
    public static final String waiting = "waiting";
    public static final String success = "success";
    public static final String fail = "fail";

    public RecognitionCheckTaskEx(RequestContext ctx, String source, String pageId, JSONObject businessParam, Map<String, Object> customParam, String url, String fileName) {
        saveCacheFile(pageId, url, "waiting");
        this.ctx = ctx;
        this.pageId = pageId;
        this.businessParam = businessParam;
        this.url = url;
        this.source = source;
        this.fileName = fileName;
        this.customParam = customParam;
    }

    public JSONObject call() throws Exception {
        logger.info("begin RecognitionCheckTaskEx :{},{}", this.url, this.fileName);

        try {
            RequestContext.copyAndSet(this.ctx);
            if (StringUtils.isEmpty(this.url)) {
                return null;
            } else {
                JSONObject invoiceResult = new JSONObject();
                Long orgId = RequestContext.get().getOrgId();
                if (this.customParam != null) {
                    try {
                        orgId = (Long)this.customParam.get("orgId");
                    } catch (Exception var12) {
                    }
                }

                boolean isZipXmlEI = FileUtils.checkFileType(this.fileName, new String[]{"zip", "xml"});
                if (isZipXmlEI) {
                    invoiceResult = EInvoiceZipXmlDealService.analysisAndCheckSave(this.url, this.fileName, orgId, this.businessParam, (IRecognitionListener)null);
                }

                boolean isNeedDeal = FileUtils.checkFileType(this.fileName, new String[]{"zip", "ofd", "xml"});
                if (isNeedDeal && !"0000".equals(invoiceResult.getString("errcode"))) {
                    invoiceResult = ElectAccVoucherService.dealVoucher(this.url, this.fileName, orgId, this.businessParam, (IRecognitionListener)null);
                }

                String xbrlErrCode = invoiceResult.getString("errcode");
                boolean dealResult = StringUtils.isEmpty(xbrlErrCode) || !xbrlErrCode.equals("0000");
                boolean isZip = FileUtils.checkFileType(this.fileName, new String[]{"zip"});
                if (dealResult && !isZip) {
                    if (FileUtils.isExcel(this.fileName)) {
                        invoiceResult = ExcelInvoiceUploadService.getInstance().uploadExcelInvoice(this.url, this.fileName, (IRecognitionListener)null, this.businessParam);
                    } else {
                        logger.info("RecognitionCheckTaskEx识别url:{}{}", this.fileName, this.url);
                        invoiceResult = RecognitionCheckServiceEx.getInstance().recognitionCheckInvoice(this.url, this.fileName, (IRecognitionListener)null, this.businessParam);
                    }
                }

                logger.info("发票助手本地上传最终数据返回：" + invoiceResult);
                if (ResultContant.isSuccess(invoiceResult)) {
                    JSONArray invoiceArray = invoiceResult.getJSONArray("data");
                    JSONArray failInvoiceArray = invoiceResult.getJSONArray("failData");
                    JSONArray attachArray = invoiceResult.getJSONArray("attach");
                    if (!CollectionUtils.isEmpty(failInvoiceArray)) {
                        CacheHelper.put(this.pageId + "failResult", failInvoiceArray.toJSONString(), cache_time_out);
                    }

                    if (invoiceArray == null && attachArray == null) {
                        saveCacheFile(this.pageId, this.url, "fail");
                    } else {
                        CacheHelper.put(this.pageId + "refresh", "1", cache_time_out);
                        if ("fpzs".equals(this.source)) {
                            Pair<JSONObject, Boolean> cachePair = FpzsMainService.cacheInvoiceList(this.pageId, this.customParam, invoiceArray, attachArray);
                            if ((Boolean)cachePair.getRight()) {
                                CacheHelper.put(this.pageId + "scannerProcessRepeat", cachePair.getRight() + "", cache_time_out);
                            }
                        } else {
                            saveCacheFileResult(this.url, invoiceArray);
                        }

                        saveCacheFile(this.pageId, this.url, "success");
                    }
                } else {
                    saveCacheFile(this.pageId, this.url, "fail");
                    saveCacheCause(this.pageId, this.url, "fail", invoiceResult.getString("description"));
                }

                return invoiceResult;
            }
        } catch (Throwable var13) {
            logger.info("RecognitionCheckTaskEx throwable:{}", var13);
            saveCacheFile(this.pageId, this.url, "fail");
            saveCacheCause(this.pageId, this.url, "fail", "程序错误");
            return new JSONObject();
        }
    }

    public JSONObject getBusinessParam() {
        return this.businessParam;
    }

    public void setBusinessParam(JSONObject businessParam) {
        this.businessParam = businessParam;
    }

    public String getUrl() {
        return this.url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public static void saveCacheFileResult(String url, JSONArray result) {
        if (result != null) {
            CacheHelper.put(MD5.md5Hex(url), result.toJSONString(), cache_time_out);
        } else {
            CacheHelper.remove(MD5.md5Hex(url));
        }

    }

    public static JSONArray queryCacheFileResult(String url) {
        String result = CacheHelper.get(MD5.md5Hex(url));
        return result != null ? JSONArray.parseArray(result) : new JSONArray();
    }

    public static void saveCacheFile(String pageId, String url, String operate) {
        cacheFile(pageId, url, operate);
    }

    public static void saveCacheCause(String pageId, String url, String operate, String cause) {
        cacheCause(pageId, url, operate, cause);
    }

    public static JSONObject queryCacheFile(String pageId) {
        return cacheFile(pageId, (String)null, "query");
    }

    public static JSONObject queryCacheCause(String pageId) {
        return cacheCause(pageId, (String)null, "query", (String)null);
    }

    public static void clearCacheFile(String pageId) {
        cacheFile(pageId, (String)null, "remove");
    }

    private static JSONObject cacheCause(String pageId, String url, String operate, String cause) {
        logger.info(pageId + url + operate + cause);
        if (StringUtils.isEmpty(pageId)) {
            return null;
        } else {
            String cacheKey = "scaner_cause_" + pageId;
            DLock lock = DLock.create("lock_" + cacheKey, "刷新卡片锁");
            Throwable var6 = null;

            JSONObject var10;
            try {
                int times = 0;

                do {
                    if (times >= 10) {
                        return null;
                    }

                    ++times;
                } while(!lock.tryLock(100L));



                try {
                    String cache;
                    if ("remove".equals(operate)) {
                        CacheHelper.remove(cacheKey);
                        cache = null;
                        return null;
                    }

                    cache = CacheHelper.get(cacheKey);
                    JSONObject obj = null;
                    if (StringUtils.isEmpty(cache)) {
                        obj = new JSONObject();
                    } else {
                        obj = JSON.parseObject(cache);
                    }

                    if ("query".equals(operate)) {
                        var10 = obj;
                        return var10;
                    }

                    if (StringUtils.isNotEmpty(url) && StringUtils.isNotEmpty(operate) && StringUtils.isNotEmpty(cause)) {
                        obj.put(url, cause);
                        CacheHelper.put(cacheKey, obj.toJSONString(), cache_time_out);
                    }

                    var10 = obj;
                } finally {
                    lock.unlock();
                }
            } catch (Throwable var29) {
                var6 = var29;
                throw var29;
            } finally {
                if (lock != null) {
                    if (var6 != null) {
                        try {
                            lock.close();
                        } catch (Throwable var27) {
                            var6.addSuppressed(var27);
                        }
                    } else {
                        lock.close();
                    }
                }

            }

            return var10;
        }
    }

    private static JSONObject cacheFile(String pageId, String url, String operate) {
        logger.info(pageId + url + operate);
        if (StringUtils.isEmpty(pageId)) {
            return null;
        } else {
            String cacheKey = "scaner_" + pageId;
            DLock lock = DLock.create("lock_" + cacheKey, "刷新卡片锁");
            Throwable var5 = null;

            try {
                int times = 0;

                while(times < 10) {
                    ++times;
                    if (lock.tryLock(100L)) {

                        try {
                            String cache;
                            if ("remove".equals(operate)) {
                                CacheHelper.remove(cacheKey);
                                cache = null;
                                return null;
                            }

                            cache = CacheHelper.get(cacheKey);
                            JSONObject obj = null;
                            if (StringUtils.isEmpty(cache)) {
                                obj = new JSONObject();
                            } else {
                                obj = JSON.parseObject(cache);
                            }

                            JSONObject var9;
                            if ("query".equals(operate)) {
                                var9 = obj;
                                return var9;
                            }

                            if (StringUtils.isNotEmpty(url) && StringUtils.isNotEmpty(operate)) {
                                obj.put(url, operate);
                                CacheHelper.put(cacheKey, obj.toJSONString(), cache_time_out);
                            }

                            var9 = obj;
                            return var9;
                        } finally {
                            lock.unlock();
                        }
                    }
                }
            } catch (Throwable var28) {
                var5 = var28;
                throw var28;
            } finally {
                if (lock != null) {
                    if (var5 != null) {
                        try {
                            lock.close();
                        } catch (Throwable var26) {
                            var5.addSuppressed(var26);
                        }
                    } else {
                        lock.close();
                    }
                }

            }

            return null;
        }
    }

    public String getSource() {
        return this.source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Map<String, Object> getCustomParam() {
        return this.customParam;
    }

    public void setCustomParam(Map<String, Object> customParam) {
        this.customParam = customParam;
    }
}
