//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by FernFlower decompiler)
//

package kd.imc.rim.common.invoice.recognitionnew.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Maps;
import java.io.ByteArrayInputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import kd.bos.logging.Log;
import kd.bos.logging.LogFactory;
import kd.bos.util.StringUtils;
import kd.imc.rim.common.constant.InputInvoiceTypeEnum;
import kd.imc.rim.common.invoice.model.ConvertFieldUtil;
import kd.imc.rim.common.invoice.query.convert.impl.AirConvertService;
import kd.imc.rim.common.invoice.recognitionnew.RecognitionService;
import kd.imc.rim.common.invoice.recognitionnew.model.RecognitionParam;
import kd.imc.rim.common.invoice.recognitionnew.model.RecognitionResult;
import kd.imc.rim.common.message.exception.MsgException;
import kd.imc.rim.common.utils.AwsFpyService;
import kd.imc.rim.common.utils.HttpUtil;
import org.apache.commons.compress.utils.Lists;

public class AwsRecognitionServiceEx implements RecognitionService {
    private static Log logger = LogFactory.getLog(AwsRecognitionService.class);
    private static final int connectionTimeout = 3000;
    private static final int readTimeout = 60000;

    public AwsRecognitionServiceEx() {
    }

    public RecognitionResult recognitionInvoice(RecognitionParam recognitionParam) {
        RecognitionResult recognitionResult = this.getResultFromDb(recognitionParam);
        if (recognitionResult == null) {
            recognitionResult = this.getResultFromAws(recognitionParam);
        }

        return recognitionResult;
    }

    private RecognitionResult getResultFromAws(RecognitionParam recognitionParam) {
        RecognitionResult recognitionResult = new RecognitionResult();
        Map<String, Object> extMap = recognitionParam.getExtMap();
        Map<String, Object> bodyMap = Maps.newHashMap();
        bodyMap.put("eid", extMap.get("eid") + "");
        bodyMap.put("taxNo", extMap.get("taxNo") + "");
        bodyMap.put("recogType", recognitionParam.getRecogType());
        bodyMap.put("overseaAppCode", recognitionParam.getAppCode());

        try {
            String serviceType = this.getServiceType(recognitionParam);
            String token = AwsFpyService.newInstance().getAccessToken(Long.parseLong(extMap.get("orgId") + ""));
            if (StringUtils.isNotEmpty(token)) {
                long start = System.currentTimeMillis();
                String url = AwsFpyService.newInstance().getUrl("pure_recognition", token);
                ByteArrayInputStream valueInputStream = recognitionParam.getFileByteArrayInputStream();
                String valueFileName = recognitionParam.getFileName();
                int retryTimes = 1;

                for(int times = 1; times <= retryTimes; ++times) {
                    String result = HttpUtil.postFormData(url + "&t=" + start, AwsFpyService.newInstance().getProxy(), (Map)null, valueInputStream, valueFileName, bodyMap, 3000, 60000);
                    logger.info("aws识别接口返回结果{}：{}", times, result);
                    boolean reTry = false;
                    if (!StringUtils.isNotEmpty(result)) {
                        break;
                    }

                    JSONArray recognitionArray = this.getRecoginitionData(recognitionResult, result);
                    if (recognitionArray == null) {
                        break;
                    }

                    boolean saveFlag = true;

                    for(int i = 0; i < recognitionArray.size(); ++i) {
                        JSONObject invoiceInfo = recognitionArray.getJSONObject(i);
                        if ("1".equals(invoiceInfo.getString("defaultOther"))) {
                            saveFlag = false;
                            if (times < retryTimes) {
                                reTry = true;
                                break;
                            }
                        }

                        this.setResultValue(invoiceInfo);
                    }

                    if (!reTry) {
                        if (saveFlag) {
                            this.saveRecognition(recognitionParam, serviceType, result, System.currentTimeMillis() - start);
                        }

                        recognitionResult.setData(this.convertRecognition(recognitionArray));
                        break;
                    }
                }
            } else {
                recognitionResult.setData(new ArrayList(1));
            }

            return recognitionResult;
        } catch (Throwable var20) {
            logger.error("AwsRecognitionService exception:", var20);
            if (var20 instanceof MsgException) {
                throw new MsgException(((MsgException)var20).getErrorCode(), ((MsgException)var20).getErrorMsg());
            } else {
                throw new MsgException("0001", "aws识别异常");
            }
        }
    }

    private RecognitionResult getResultFromDb(RecognitionParam recognitionParam) {
        RecognitionResult recognitionResult = new RecognitionResult();
        String serviceType = this.getServiceType(recognitionParam);
        String resultStr = this.getRecognitionResultFromDb(recognitionParam, serviceType);
        if (StringUtils.isEmpty(resultStr)) {
            return null;
        } else {
            JSONArray recognitionArray = this.getRecoginitionData(recognitionResult, resultStr);
            if (recognitionArray == null) {
                return null;
            } else {
                for(int i = 0; i < recognitionArray.size(); ++i) {
                    JSONObject invoiceInfo = recognitionArray.getJSONObject(i);
                    this.setResultValue(invoiceInfo);
                }

                recognitionResult.setData(this.convertRecognition(recognitionArray));
                return recognitionResult;
            }
        }
    }

    private JSONArray getRecoginitionData(RecognitionResult recognitionResult, String resultStr) {
        if (StringUtils.isNotEmpty(resultStr)) {
            JSONObject recognitionJson = JSONObject.parseObject(resultStr);
            recognitionResult.setErrcode(recognitionJson.getString("errcode"));
            recognitionResult.setDescription(recognitionJson.getString("description"));
            JSONObject data = recognitionJson.getJSONObject("data");
            if (data != null) {
                JSONArray recognitionArray = data.getJSONArray("recoginitionData");
                return recognitionArray;
            }
        }

        return null;
    }

    private void setResultValue(JSONObject invoiceInfo) {
        invoiceInfo.put("snapshotUrl", "");
        invoiceInfo.put("kdcloudUrl", "");
        invoiceInfo.put("downloadUrl", "");
        Long invoiceType = InputInvoiceTypeEnum.getInvoiceTypeByAwsType(invoiceInfo.getString("invoiceType"));
        invoiceInfo.put("invoiceType", invoiceType);
        if (InputInvoiceTypeEnum.AIR_INVOICE.getCode().equals(invoiceType)) {
            JSONArray items = invoiceInfo.getJSONArray("items");
            if (items != null && items.size() > 0) {
                JSONObject firstOne = items.getJSONObject(0);
                invoiceInfo.put("seatGrade", firstOne.getString("seatGrade"));
                invoiceInfo.put("flightNum", firstOne.getString("flightNum"));
                invoiceInfo.put("seatGradeName", AirConvertService.convertSeatName(firstOne.getString("seatGrade")));
            }
        }

    }

    private List<Object> convertRecognition(JSONArray recognitionArray) {
        List<Object> entityList = Lists.newArrayList();
        ConvertFieldUtil.convertRecognitionEntity(entityList, recognitionArray, new String[]{"items"});
        return entityList;
    }

    public String getServiceType(RecognitionParam recognitionParam) {
        return "aws" + recognitionParam.getRecogType();
    }
}
